@@ -1238,7 +1238,7 @@ void D4ParserSax2::cleanup_parse()
     bool wellFormed = d_context->wellFormed;
     bool valid = d_context->valid;
 
-    d_context->sax = NULL;
+    // d_context->sax = NULL;
     xmlFreeParserCtxt(d_context);
 
     delete d_enum_def;
@@ -1290,7 +1290,7 @@ void D4ParserSax2::intern(istream &f, DMR *dest_dmr, bool debug)
         throw InternalErr(__FILE__, __LINE__, "DMR object is null");
 
     d_dmr = dest_dmr; // dump values here
-
+#if 0
     int line_num = 1;
     string line;
 
@@ -1319,10 +1319,47 @@ void D4ParserSax2::intern(istream &f, DMR *dest_dmr, bool debug)
 
         if (debug) cerr << "line: (" << line_num << "): " << endl << line << endl << endl;
     }
-
     // This call ends the parse.
     xmlParseChunk(d_context, line.c_str(), 0, 1/*terminate*/);
 
+#else
+    int line_num = 1;
+    string line;
+
+    // Get the XML prolog line (looks like: <?xml ... ?> )
+    getline(f, line);
+    if (line.length() == 0) throw Error("No input found while parsing the DMR.");
+
+    if (debug) cerr << "line: (" << line_num << "): " << endl << line << endl << endl;
+
+    d_context = xmlCreatePushParserCtxt(&d_dmr_sax_parser, this, line.c_str(), line.length(), "stream");
+    d_context->validate = true;
+    push_state(parser_start);
+
+    // Get the first chunk of the stuff
+    long chunk_count = 0;
+    long chunk_size = 0;
+
+    f.read(d_parse_buffer, D4_PARSE_BUFF_SIZE);
+    chunk_size=f.gcount();
+    d_parse_buffer[chunk_size]=0; // null terminate the string. We can do it this way because the buffer is +1 bigger than D4_PARSE_BUFF_SIZE
+    if (debug) cerr << "chunk: (" << chunk_count++ << "): " << endl << d_parse_buffer << endl << endl;
+
+    while(!f.eof()  && (get_state() != parser_end)){
+
+        xmlParseChunk(d_context, d_parse_buffer, chunk_size, 0);
+
+        // There is more to read. Get the next chunk
+        f.read(d_parse_buffer, D4_PARSE_BUFF_SIZE);
+        chunk_size=f.gcount();
+        d_parse_buffer[chunk_size]=0; // null terminate the string. We can do it this way because the buffer is +1 bigger than D4_PARSE_BUFF_SIZE
+        if (debug) cerr << "chunk: (" << chunk_count++ << "): " << endl << d_parse_buffer << endl << endl;
+    }
+
+    // This call ends the parse.
+    xmlParseChunk(d_context, d_parse_buffer, chunk_size, 1/*terminate*/);
+#endif
+
     // This checks that the state on the parser stack is parser_end and throws
     // an exception if it's not (i.e., the loop exited with gcount() == 0).
     cleanup_parse();
