@@ -133,7 +133,7 @@ public:
      *
      * @note Added so that the NCML handler can code some optimizations in its
      * specialized versions of Array. jhrg 8/14/15
-     * @return A reference to the data buffer for Vectors/Arrays of the cardinal types.
+     * @return A pointer to the data buffer for Vectors/Arrays of the cardinal types.
      */
     char *get_buf() {
         return d_buf;
@@ -190,7 +190,7 @@ public:
 
     // DAP4
     virtual void compute_checksum(Crc32 &checksum);
-    virtual void intern_data(Crc32 &checksum);
+    virtual void intern_data(/*Crc32 &checksum*/);
     virtual void serialize(D4StreamMarshaller &m, DMR &dmr, bool filter = false);
 #if 0
     virtual void serialize_no_release(D4StreamMarshaller &m, DMR &dmr, bool filter = false);
