@@ -10,6 +10,6 @@
 #ifndef CGI_UTIL_H_
 #define CGI_UTIL_H_
 
-#include <>mime_util.h>
+#include <mime_util.h>
 
 #endif /* CGI_UTIL_H_ */
