@@ -41,7 +41,7 @@
 
 
 // Unqualified %code blocks.
-#line 77 "d4_ce_parser.yy" // lalr1.cc:435
+#line 78 "d4_ce_parser.yy" // lalr1.cc:435
 
    #include <iostream>
    #include <cstdlib>
@@ -154,7 +154,7 @@
 #define YYERROR         goto yyerrorlab
 #define YYRECOVERING()  (!!yyerrstatus_)
 
-#line 35 "d4_ce_parser.yy" // lalr1.cc:510
+#line 36 "d4_ce_parser.yy" // lalr1.cc:510
 namespace libdap {
 #line 160 "d4_ce_parser.tab.cc" // lalr1.cc:510
 
@@ -695,7 +695,7 @@ namespace libdap {
 
 
     // User initialization code.
-#line 69 "d4_ce_parser.yy" // lalr1.cc:791
+#line 70 "d4_ce_parser.yy" // lalr1.cc:791
 {
     // Initialize the initial location. This is printed when the parser builds
     // its own error messages - when the parse fails as opposed to when the 
@@ -971,7 +971,7 @@ namespace libdap {
     
     if (btp->type() == dods_array_c) {
         if (btp->var() && !btp->var()->is_constructor_type())
-            throw Error(no_such_variable, "The variable " + yystack_[0].value.as < std::string > () + " must be a Structure or Sequence to be used with {}.");
+            throw Error(no_such_variable, "The constraint expression referenced a variable that must be a Structure or Sequence to be used with {}.");
             
         // This call also tests the btp to make sure it's an array
         driver.mark_array_variable(btp);
@@ -980,7 +980,7 @@ namespace libdap {
         // Don't mark the variable here because only some fields are to be sent and those
         // will be marked when the fields are parsed
         if (!btp->is_constructor_type())
-            throw Error(no_such_variable, "The variable " + yystack_[0].value.as < std::string > () + " must be a Structure or Sequence to be used with {}.");
+            throw Error(no_such_variable, "The constraint expression referenced a variable that must be a Structure or Sequence to be used with {}.");
     }
     
     // push the basetype so that it is
@@ -1020,7 +1020,7 @@ namespace libdap {
     driver.mark_array_variable(btp);
     
     if (!btp->var()->is_constructor_type())
-        throw Error(no_such_variable, "The variable " + yystack_[1].value.as < std::string > () + " must be a Structure or Sequence to be used with {}.");
+        throw Error(no_such_variable, "The constraint expression referenced a variable that must be a Structure or Sequence to be used with {}.");
       
     driver.push_basetype(btp->var());       
 }
@@ -1029,253 +1029,252 @@ namespace libdap {
 
   case 16:
 #line 292 "d4_ce_parser.yy" // lalr1.cc:919
-    { 
-    //driver.pop_basetype();
+    {
     yylhs.value.as < bool > () = true; 
 }
-#line 1037 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1036 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 17:
-#line 303 "d4_ce_parser.yy" // lalr1.cc:919
+#line 299 "d4_ce_parser.yy" // lalr1.cc:919
     { 
     driver.push_index(yystack_[0].value.as < libdap::D4ConstraintEvaluator::index > ()); 
     yylhs.value.as < bool > () = true; 
 }
-#line 1046 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1045 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 18:
-#line 307 "d4_ce_parser.yy" // lalr1.cc:919
+#line 303 "d4_ce_parser.yy" // lalr1.cc:919
     { driver.push_index(yystack_[0].value.as < libdap::D4ConstraintEvaluator::index > ()); }
-#line 1052 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1051 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 19:
-#line 307 "d4_ce_parser.yy" // lalr1.cc:919
+#line 303 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < bool > () = yystack_[0].value.as < bool > (); }
-#line 1058 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1057 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 20:
-#line 312 "d4_ce_parser.yy" // lalr1.cc:919
+#line 308 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < libdap::D4ConstraintEvaluator::index > () = driver.make_index(); }
-#line 1064 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1063 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 21:
-#line 313 "d4_ce_parser.yy" // lalr1.cc:919
+#line 309 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < libdap::D4ConstraintEvaluator::index > () = driver.make_index(yystack_[1].value.as < std::string > ()); }
-#line 1070 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1069 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 22:
-#line 314 "d4_ce_parser.yy" // lalr1.cc:919
+#line 310 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < libdap::D4ConstraintEvaluator::index > () = driver.make_index(yystack_[3].value.as < std::string > (), 1, yystack_[1].value.as < std::string > ()); }
-#line 1076 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1075 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 23:
-#line 315 "d4_ce_parser.yy" // lalr1.cc:919
+#line 311 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < libdap::D4ConstraintEvaluator::index > () = driver.make_index(yystack_[5].value.as < std::string > (), yystack_[3].value.as < std::string > (), yystack_[1].value.as < std::string > ()); }
-#line 1082 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1081 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 24:
-#line 316 "d4_ce_parser.yy" // lalr1.cc:919
+#line 312 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < libdap::D4ConstraintEvaluator::index > () = driver.make_index(yystack_[2].value.as < std::string > (), 1); }
-#line 1088 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1087 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 25:
-#line 317 "d4_ce_parser.yy" // lalr1.cc:919
+#line 313 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < libdap::D4ConstraintEvaluator::index > () = driver.make_index(yystack_[4].value.as < std::string > (), yystack_[2].value.as < std::string > ()); }
-#line 1094 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1093 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 26:
-#line 320 "d4_ce_parser.yy" // lalr1.cc:919
+#line 316 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < bool > () = yystack_[1].value.as < bool > (); }
-#line 1100 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1099 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 27:
-#line 326 "d4_ce_parser.yy" // lalr1.cc:919
+#line 322 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < bool > () = true; }
-#line 1106 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1105 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 28:
-#line 327 "d4_ce_parser.yy" // lalr1.cc:919
+#line 323 "d4_ce_parser.yy" // lalr1.cc:919
     { yylhs.value.as < bool > () = yystack_[2].value.as < bool > () && yystack_[0].value.as < bool > (); }
-#line 1112 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1111 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 29:
-#line 339 "d4_ce_parser.yy" // lalr1.cc:919
+#line 335 "d4_ce_parser.yy" // lalr1.cc:919
     { driver.add_filter_clause(yystack_[1].value.as < std::string > (), yystack_[2].value.as < std::string > (), yystack_[0].value.as < std::string > ()); yylhs.value.as < bool > () = true; }
-#line 1118 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1117 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 30:
-#line 342 "d4_ce_parser.yy" // lalr1.cc:919
+#line 338 "d4_ce_parser.yy" // lalr1.cc:919
     { 
     driver.add_filter_clause(yystack_[3].value.as < std::string > (), yystack_[4].value.as < std::string > (), yystack_[2].value.as < std::string > ()); 
     driver.add_filter_clause(yystack_[1].value.as < std::string > (), yystack_[2].value.as < std::string > (), yystack_[0].value.as < std::string > ()); 
     yylhs.value.as < bool > () = true; 
 
 }
-#line 1129 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1128 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 31:
-#line 348 "d4_ce_parser.yy" // lalr1.cc:919
+#line 344 "d4_ce_parser.yy" // lalr1.cc:919
     { throw Error(malformed_expr, "The 'ND' operator is not currently supported."); }
-#line 1135 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1134 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 32:
-#line 356 "d4_ce_parser.yy" // lalr1.cc:919
+#line 352 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = "<";}
-#line 1141 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1140 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 33:
-#line 357 "d4_ce_parser.yy" // lalr1.cc:919
+#line 353 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = ">";}
-#line 1147 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1146 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 34:
-#line 358 "d4_ce_parser.yy" // lalr1.cc:919
+#line 354 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = "<=";}
-#line 1153 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1152 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 35:
-#line 359 "d4_ce_parser.yy" // lalr1.cc:919
+#line 355 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = ">=";}
-#line 1159 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1158 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 36:
-#line 360 "d4_ce_parser.yy" // lalr1.cc:919
+#line 356 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = "==";}
-#line 1165 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1164 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 37:
-#line 361 "d4_ce_parser.yy" // lalr1.cc:919
+#line 357 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = "!=";}
-#line 1171 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1170 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 38:
-#line 362 "d4_ce_parser.yy" // lalr1.cc:919
+#line 358 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = "~=";}
-#line 1177 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1176 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 39:
-#line 364 "d4_ce_parser.yy" // lalr1.cc:919
+#line 360 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = "<<";}
-#line 1183 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1182 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 40:
-#line 365 "d4_ce_parser.yy" // lalr1.cc:919
+#line 361 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = ">>";}
-#line 1189 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1188 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 41:
-#line 367 "d4_ce_parser.yy" // lalr1.cc:919
+#line 363 "d4_ce_parser.yy" // lalr1.cc:919
     {yylhs.value.as < std::string > () = "@=";}
-#line 1195 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1194 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 42:
-#line 371 "d4_ce_parser.yy" // lalr1.cc:919
+#line 367 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > () = yystack_[0].value.as < std::string > ();
 }
-#line 1203 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1202 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 43:
-#line 375 "d4_ce_parser.yy" // lalr1.cc:919
+#line 371 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ().append("/");
     yylhs.value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
 }
-#line 1212 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1211 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 44:
-#line 380 "d4_ce_parser.yy" // lalr1.cc:919
+#line 376 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append("/");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1222 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1221 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 45:
-#line 388 "d4_ce_parser.yy" // lalr1.cc:919
+#line 384 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ().append("/");
     yylhs.value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
 }
-#line 1231 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1230 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 46:
-#line 393 "d4_ce_parser.yy" // lalr1.cc:919
+#line 389 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append("/");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1241 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1240 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 47:
-#line 401 "d4_ce_parser.yy" // lalr1.cc:919
+#line 397 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > () = yystack_[0].value.as < std::string > ();
 }
-#line 1249 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1248 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 48:
-#line 405 "d4_ce_parser.yy" // lalr1.cc:919
+#line 401 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append(".");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1259 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1258 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 49:
-#line 422 "d4_ce_parser.yy" // lalr1.cc:919
+#line 418 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ()=www2id(yystack_[0].value.as < std::string > ());
 }
-#line 1267 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1266 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 50:
-#line 426 "d4_ce_parser.yy" // lalr1.cc:919
+#line 422 "d4_ce_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ()=driver.remove_quotes(yystack_[0].value.as < std::string > ());
 }
-#line 1275 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1274 "d4_ce_parser.tab.cc" // lalr1.cc:919
     break;
 
 
-#line 1279 "d4_ce_parser.tab.cc" // lalr1.cc:919
+#line 1278 "d4_ce_parser.tab.cc" // lalr1.cc:919
             default:
               break;
             }
@@ -1671,11 +1670,11 @@ namespace libdap {
   D4CEParser::yyrline_[] =
   {
        0,   148,   148,   149,   152,   153,   156,   162,   163,   173,
-     177,   184,   204,   229,   228,   268,   267,   302,   307,   307,
-     312,   313,   314,   315,   316,   317,   320,   326,   327,   338,
-     341,   348,   356,   357,   358,   359,   360,   361,   362,   364,
-     365,   367,   370,   374,   379,   387,   392,   400,   404,   421,
-     425
+     177,   184,   204,   229,   228,   268,   267,   298,   303,   303,
+     308,   309,   310,   311,   312,   313,   316,   322,   323,   334,
+     337,   344,   352,   353,   354,   355,   356,   357,   358,   360,
+     361,   363,   366,   370,   375,   383,   388,   396,   400,   417,
+     421
   };
 
   // Print the state stack on the debug stream.
@@ -1757,10 +1756,10 @@ namespace libdap {
       return undef_token_;
   }
 
-#line 35 "d4_ce_parser.yy" // lalr1.cc:1242
+#line 36 "d4_ce_parser.yy" // lalr1.cc:1242
 } // libdap
-#line 1763 "d4_ce_parser.tab.cc" // lalr1.cc:1242
-#line 431 "d4_ce_parser.yy" // lalr1.cc:1243
+#line 1762 "d4_ce_parser.tab.cc" // lalr1.cc:1242
+#line 427 "d4_ce_parser.yy" // lalr1.cc:1243
 
 
 // Forward the error to the driver for handling. The location parameter
