@@ -45,6 +45,9 @@
 #include "Grid.h"
 
 #include "DDS.h"
+#include "DMR.h"
+#include "D4ParserSax2.h"
+#include "D4BaseTypeFactory.h"
 
 #include "GNURegex.h"
 #include "GetOpt.h"
@@ -111,7 +114,7 @@ public:
     // to work with transfer_attributes() - if a handler builds a malformed
     // DAS, it will need to specialize the BaseType::transfer_attributes()
     // method.
-CPPUNIT_TEST_SUITE (DDSTest);
+    CPPUNIT_TEST_SUITE (DDSTest);
     CPPUNIT_TEST(transfer_attributes_test_1);
     CPPUNIT_TEST(transfer_attributes_test_2);
 
@@ -142,8 +145,14 @@ CPPUNIT_TEST_SUITE (DDSTest);
     // see comment in code below. jhrg 2/4/14 CPPUNIT_TEST(get_response_size_test_seq);
     CPPUNIT_TEST(get_response_size_test_seq_c);
 
-    CPPUNIT_TEST_SUITE_END()
-    ;
+    CPPUNIT_TEST(get_das_test_1);
+    CPPUNIT_TEST(get_das_test_2);
+    CPPUNIT_TEST(get_das_test_3);
+    CPPUNIT_TEST(get_das_test_4);
+    CPPUNIT_TEST(get_das_test_5);
+    CPPUNIT_TEST(get_das_test_6);
+
+    CPPUNIT_TEST_SUITE_END();
 
     void transfer_attributes_test_1()
     {
@@ -153,7 +162,7 @@ CPPUNIT_TEST_SUITE (DDSTest);
             das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
             dds1->transfer_attributes(&das);
 
-            DBG2(dds1->print_xml(cerr, false, ""));
+            DBG(dds1->print_xml(cerr, false, ""));
 
             AttrTable &at = dds1->get_attr_table();
             AttrTable::Attr_iter i = at.attr_begin();
@@ -174,7 +183,7 @@ CPPUNIT_TEST_SUITE (DDSTest);
             das.parse((string) TEST_SRC_DIR + "/dds-testsuite/3B42.980909.5.hacked.HDF.das");
             dds2->transfer_attributes(&das);
 
-            DBG2(dds2->print_xml(cerr, false, ""));
+            DBG(dds2->print_xml(cerr, false, ""));
 
             AttrTable &at = dds2->get_attr_table();
             AttrTable::Attr_iter i = at.attr_begin();
@@ -213,10 +222,14 @@ CPPUNIT_TEST_SUITE (DDSTest);
             dds2->parse((string) TEST_SRC_DIR + "/dds-testsuite/test.19b");
             ostringstream oss;
             dds2->print_xml_writer(oss, false, "http://localhost/dods/test.xyz");
-            DBG2(cerr << "Printed DDX: " << oss.str() << endl);
+            DBG(cerr << "Printed DDX: " << oss.str() << endl);
 
-            string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19b.xml");
-            DBG2(cerr << "The baseline: " << baseline << endl);
+#if DAP2_DDX
+            string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19b.dap2.xml");
+#else
+            string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19b.xml");
+#endif
+            DBG(cerr << "The baseline: " << baseline << endl);
 
             CPPUNIT_ASSERT(baseline == oss.str());
         }
@@ -237,10 +250,14 @@ CPPUNIT_TEST_SUITE (DDSTest);
         ostringstream oss;
         dds2->print_xml_writer(oss, false, "http://localhost/dods/test.xyz");
 
-        DBG2(cerr << oss.str() << endl);
+        DBG(cerr << oss.str() << endl);
 
-        string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19c.xml");
-        DBG2(cerr << baseline << endl);
+#if DAP2_DDX
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19c.dap2.xml");
+#else
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19c.xml");
+#endif
+        DBG(cerr << baseline << endl);
         CPPUNIT_ASSERT(baseline == oss.str());
     }
 
@@ -255,10 +272,15 @@ CPPUNIT_TEST_SUITE (DDSTest);
         ostringstream oss;
         dds2->print_xml_writer(oss, false, "http://localhost/dods/test.xyz");
 
-        DBG2(cerr << oss.str() << endl);
+        DBG(cerr << oss.str() << endl);
 
-        string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19d.xml");
-        DBG2(cerr << baseline << endl);
+#if DAP2_DDX
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19d.dap2.xml");
+#else
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19d.xml");
+#endif
+
+        DBG(cerr << baseline << endl);
         CPPUNIT_ASSERT(baseline == oss.str());
     }
 
@@ -275,10 +297,10 @@ CPPUNIT_TEST_SUITE (DDSTest);
         ostringstream oss;
         dds2->print_xml_writer(oss, false, "http://localhost/dods/test.xyz");
 
-        DBG2(cerr << oss.str() << endl);
+        DBG(cerr << oss.str() << endl);
 
-        string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19d1.xml");
-        DBG2(cerr << baseline << endl);
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19d1.xml");
+        DBG(cerr << baseline << endl);
         CPPUNIT_ASSERT(baseline == oss.str());
     }
 
@@ -297,8 +319,12 @@ CPPUNIT_TEST_SUITE (DDSTest);
 
         DBG(cerr << oss.str() << endl);
 
-        string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19e.xml");
-        DBG2(cerr << baseline << endl);
+#if DAP2_DDX
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19e.dap2.xml");
+#else
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19e.xml");
+#endif
+        DBG(cerr << baseline << endl);
         CPPUNIT_ASSERT(baseline == oss.str());
     }
 
@@ -309,8 +335,13 @@ CPPUNIT_TEST_SUITE (DDSTest);
         DAS das;
         string das_file((string) TEST_SRC_DIR + "/dds-testsuite/test.19f.das");
         das.parse(das_file);
+
+#if DAP2_DDX
+        string baseline_file((string) TEST_SRC_DIR + "/dds-testsuite/test.19f.dap2.xml");
+#else
         string baseline_file((string) TEST_SRC_DIR + "/dds-testsuite/test.19f.xml");
-        string baseline = readTestBaseline(baseline_file);
+#endif
+        string baseline = read_test_baseline(baseline_file);
 
         try {
             dds2->transfer_attributes(&das);
@@ -357,8 +388,8 @@ CPPUNIT_TEST_SUITE (DDSTest);
 
         DBG(cerr << oss.str() << endl);
 
-        string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19f1.xml");
-        DBG2(cerr << baseline << endl);
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19f1.xml");
+        DBG(cerr << baseline << endl);
         CPPUNIT_ASSERT(baseline == oss.str());
     }
 
@@ -375,8 +406,13 @@ CPPUNIT_TEST_SUITE (DDSTest);
 
         DBG(cerr << oss.str() << endl);
 
-        string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19b6.xml");
-        DBG2(cerr << baseline << endl);
+#if DAP2_DDX
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19b6.dap2.xml");
+#else
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19b6.xml");
+#endif
+
+        DBG(cerr << baseline << endl);
         CPPUNIT_ASSERT(baseline == oss.str());
     }
 
@@ -403,8 +439,8 @@ CPPUNIT_TEST_SUITE (DDSTest);
 
         DBG(cerr << oss.str() << endl);
 
-        string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19g.xml");
-        DBG2(cerr << baseline << endl);
+        string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/test.19g.xml");
+        DBG(cerr << baseline << endl);
         CPPUNIT_ASSERT(baseline == oss.str());
     }
 
@@ -424,7 +460,7 @@ CPPUNIT_TEST_SUITE (DDSTest);
             ostringstream oss;
             dds_dap4->print_dmr(oss, false);
 
-            string baseline = readTestBaseline((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dmr.xml");
+            string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dmr.xml");
 
             DBG(cerr << "Baseline: -->" << baseline << "<--" << endl);
             DBG(cerr << "DMR: -->" << oss.str() << "<--" << endl);
@@ -508,6 +544,174 @@ CPPUNIT_TEST_SUITE (DDSTest);
         CPPUNIT_ASSERT(dds2->get_request_size(true) == 4);
     }
 
+    // Build a DDS with attributes, then check that get_das() returns the correct thing
+    void get_das_test_1() {
+        try {
+            BaseTypeFactory btf;
+            DDS dds(&btf);
+            dds.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dds");
+            DAS das;
+            das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
+            dds.transfer_attributes(&das);
+
+            auto_ptr<DAS> new_das(dds.get_das());
+
+            string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
+            ostringstream oss;
+            new_das->print(oss);
+
+            DBG(cerr << "Baseline: -->" << baseline << "<--" << endl);
+            DBG(cerr << "DAS: -->" << oss.str() << "<--" << endl);
+
+            CPPUNIT_ASSERT(baseline == oss.str());
+        }
+        catch (Error &e) {
+            CPPUNIT_FAIL(e.get_error_message());
+        }
+    }
+
+    // Build a DMR, then check that get_das() returns the correct thing. Note that the
+    // order of the attr tables is not exactly the same because the DMR treats Grids
+    // differently. In the DMR, DAP2 Grid maps become shared dimensions and those are
+    // output last. In a DAP2 DDS, they (maps) are added as 'extra' variables are written
+    // first. Thus the attribute containers for maps/shared dims are either first or last
+    // for DAP2 or DAP4, resp.
+    void get_das_test_2() {
+        try {
+            D4BaseTypeFactory d4_factory;
+            DMR dmr(&d4_factory);
+            D4ParserSax2 parser;
+
+            ifstream ifs((string(TEST_SRC_DIR) + "/dmr-testsuite/coads_climatology.nc.full.dmr").c_str());
+
+            parser.intern(ifs, &dmr);
+
+            auto_ptr<DDS> dds(dmr.getDDS());
+            auto_ptr<DAS> das(dds->get_das());
+
+            string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/dmr-testsuite/coads_climatology.nc.full.dmr.das");
+            ostringstream oss;
+            das->print(oss);
+
+            DBG(cerr << "Baseline: -->" << baseline << "<--" << endl);
+            DBG(cerr << "DAS: -->" << oss.str() << "<--" << endl);
+
+            CPPUNIT_ASSERT(baseline == oss.str());
+        }
+        catch (Error &e) {
+            CPPUNIT_FAIL(e.get_error_message());
+        }
+    }
+
+    // Test the case whee there are no attribtues for variables
+    void get_das_test_3() {
+        try {
+            BaseTypeFactory btf;
+            DDS dds(&btf);
+            dds.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dds");
+            DAS das;
+            das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das.no_var");
+            dds.transfer_attributes(&das);
+
+            auto_ptr<DAS> new_das(dds.get_das());
+
+            string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das.no_var");
+            ostringstream oss;
+            new_das->print(oss);
+
+            DBG(cerr << "Baseline: -->" << baseline << "<--" << endl);
+            DBG(cerr << "DAS: -->" << oss.str() << "<--" << endl);
+
+            CPPUNIT_ASSERT(baseline == oss.str());
+        }
+        catch (Error &e) {
+            CPPUNIT_FAIL(e.get_error_message());
+        }
+    }
+
+    // Test the case where there are no global attributes
+    void get_das_test_4() {
+        try {
+            BaseTypeFactory btf;
+            DDS dds(&btf);
+            dds.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dds");
+            DAS das;
+            das.parse((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das.no_global");
+            dds.transfer_attributes(&das);
+
+            auto_ptr<DAS> new_das(dds.get_das());
+
+            string baseline = read_test_baseline((string) TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das.no_global");
+            ostringstream oss;
+            new_das->print(oss);
+
+            DBG(cerr << "Baseline: -->" << baseline << "<--" << endl);
+            DBG(cerr << "DAS: -->" << oss.str() << "<--" << endl);
+
+            CPPUNIT_ASSERT(baseline == oss.str());
+        }
+        catch (Error &e) {
+            CPPUNIT_FAIL(e.get_error_message());
+        }
+    }
+
+    // Test the case where there are orphaned global attributes (one w/o an enclosing container).
+    void get_das_test_5()
+    {
+        try {
+            D4BaseTypeFactory d4_factory;
+            DMR dmr(&d4_factory);
+            D4ParserSax2 parser;
+
+            ifstream ifs((string(TEST_SRC_DIR) + "/dmr-to-dap2-testsuite/1A.GPM.GMI.COUNT2014v3.20160105.h5.dmrpp.dmr").c_str());
+
+            parser.intern(ifs, &dmr);
+
+            auto_ptr<DDS> dds(dmr.getDDS());
+            auto_ptr<DAS> das(dds->get_das());
+
+            string baseline = read_test_baseline(string(TEST_SRC_DIR) +  "/dmr-to-dap2-testsuite/1A.GPM.GMI.COUNT2014v3.20160105.h5.dmrpp.dmr.baseline");
+            ostringstream oss;
+            das->print(oss);
+
+            DBG(cerr << "Baseline: -->" << baseline << "<--" << endl);
+            DBG(cerr << "DAS: -->" << oss.str() << "<--" << endl);
+
+            CPPUNIT_ASSERT(baseline == oss.str());
+        }
+        catch (Error &e) {
+            CPPUNIT_FAIL(e.get_error_message());
+        }
+    }
+
+    // Test the code that tests for a unique top-level attribute container name for orphaned TL attributes.
+    void get_das_test_6() {
+        try {
+            D4BaseTypeFactory d4_factory;
+            DMR dmr(&d4_factory);
+            D4ParserSax2 parser;
+
+            ifstream ifs((string(TEST_SRC_DIR) + "/dmr-to-dap2-testsuite/hacked.dmrpp.dmr").c_str());
+
+            parser.intern(ifs, &dmr);
+
+            auto_ptr<DDS> dds(dmr.getDDS());
+            auto_ptr<DAS> das(dds->get_das());
+
+            string baseline = read_test_baseline(string(TEST_SRC_DIR) +  "/dmr-to-dap2-testsuite/hacked.dmrpp.dmr.baseline");
+            ostringstream oss;
+            das->print(oss);
+
+            DBG(cerr << "Baseline: -->" << baseline << "<--" << endl);
+            DBG(cerr << "DAS: -->" << oss.str() << "<--" << endl);
+
+            CPPUNIT_ASSERT(baseline == oss.str());
+        }
+        catch (Error &e) {
+            CPPUNIT_FAIL(e.get_error_message());
+        }
+    }
+
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(DDSTest);
